# How to submit an Issue

When submitting an Issue to the `qary` repository, it will help if you follow this template:

## Environment

Tell us what OS you are using and how you installed the bot (`conda`, `pip`, `setup.py`, or manually).

You can use `git branch` to find the branch you are using.
Bonus points if you find the latest commit hash (ref spec) were you found the issue.
You can use `git log | head -n 1` to see the commit hash.
You can find the latest tag for your version with `


## Repro

Show us how to replicate the Issue. For example:

1. launch the bot with `bot -vv -b qa`
2. Ask "What is a chatbot?" and it will respond with an unrelated answer.
